import { h } from 'preact';
import * as styles from './search-field.scss';
import { InputField } from '@playkit-js/common/dist/components/input-field';
import { withText, Text } from 'preact-i18n';
import { ClearSearchIcon } from '../icons/clear-search-icon';

const translations = {
  searchInputPlaceholder: <Text id="taxonomyTranscript.search.placeholder">Search in transcript</Text>,
  clearTextLabel: <Text id="taxonomyTranscript.search.clear">Clear search</Text>
};

interface Props {
  searchValue: string;
  onChange: (value: string) => void;
}
export const SearchField = withText(translations)(({
  searchValue,
  onChange,
  searchInputPlaceholder,
  clearTextLabel
}: Props & { searchInputPlaceholder: string; clearTextLabel: string }): h.JSX.Element => {
  function handleClearIconClick(): void {
    onChange('');
  }

  return (
    <div className={styles.wrapper}>
      <InputField placeholder={searchInputPlaceholder} value={searchValue} onChange={onChange} />
      {searchValue !== '' ? (
        <button aria-label={clearTextLabel} className={styles.clearIcon} onClick={handleClearIconClick}>
          {<ClearSearchIcon />}
        </button>
      ) : null}
    </div>
  );
});
